@@ -3,6 +3,7 @@ import asyncio
 import base64
 import copy
 import json
+import logging
 import os
 from datetime import timedelta
 
@@ -20,12 +21,14 @@ from .handshake import REGISTRATION_MESSAGE
 
 SOUND_OUTPUTS_TO_DELAY_CONSECUTIVE_VOLUME_STEPS = {"external_arc"}
 
+_LOGGER = logging.getLogger(__package__)
+
 
 class WebOsClient:
     """webOS TV client class."""
 
     def __init__(
-        self, host, client_key=None, timeout_connect=2, ping_interval=1, ping_timeout=20
+        self, host, client_key=None, timeout_connect=2, ping_interval=5, ping_timeout=20
     ):
         """Initialize the client."""
         self.host = host
@@ -102,7 +105,8 @@ class WebOsClient:
             main_ws = await asyncio.wait_for(
                 ws_connect(
                     f"ws://{self.host}:{self.port}",
-                    ping_interval=None,
+                    ping_interval=self.ping_interval,
+                    ping_timeout=self.ping_timeout,
                     close_timeout=self.timeout_connect,
                     max_size=None,
                 ),
@@ -110,8 +114,10 @@ class WebOsClient:
             )
 
             # send hello
+            _LOGGER.debug("send(%s): hello", self.host)
             await main_ws.send(json.dumps({"id": "hello", "type": "hello"}))
             raw_response = await main_ws.recv()
+            _LOGGER.debug("recv(%s): %s", self.host, raw_response)
             response = json.loads(raw_response)
 
             if response["type"] == "hello":
@@ -120,8 +126,10 @@ class WebOsClient:
                 raise WebOsTvCommandError(f"Invalid request type {response}")
 
             # send registration
+            _LOGGER.debug("send(%s): registration", self.host)
             await main_ws.send(json.dumps(self.registration_msg()))
             raw_response = await main_ws.recv()
+            _LOGGER.debug("recv(%s): registration", self.host)
             response = json.loads(raw_response)
 
             if (
@@ -129,6 +137,7 @@ class WebOsClient:
                 and response["payload"]["pairingType"] == "PROMPT"
             ):
                 raw_response = await main_ws.recv()
+                _LOGGER.debug("recv(%s): pairing", self.host)
                 response = json.loads(raw_response)
                 if response["type"] == "registered":
                     self.client_key = response["payload"]["client-key"]
@@ -144,14 +153,6 @@ class WebOsClient:
                     self.consumer_handler(main_ws, self.callbacks, self.futures)
                 )
             )
-            if self.ping_interval is not None:
-                handler_tasks.add(
-                    asyncio.create_task(
-                        self.ping_handler(
-                            main_ws, self.ping_interval, self.ping_timeout
-                        )
-                    )
-                )
             self.connection = main_ws
 
             # open additional connection needed to send button commands
@@ -162,21 +163,14 @@ class WebOsClient:
             input_ws = await asyncio.wait_for(
                 ws_connect(
                     inputsockpath,
-                    ping_interval=None,
+                    ping_interval=self.ping_interval,
+                    ping_timeout=self.ping_timeout,
                     close_timeout=self.timeout_connect,
                 ),
                 timeout=self.timeout_connect,
             )
 
             handler_tasks.add(asyncio.create_task(input_ws.wait_closed()))
-            if self.ping_interval is not None:
-                handler_tasks.add(
-                    asyncio.create_task(
-                        self.ping_handler(
-                            input_ws, self.ping_interval, self.ping_timeout
-                        )
-                    )
-                )
             self.input_connection = input_ws
 
             # set static state and subscribe to state updates
@@ -216,6 +210,7 @@ class WebOsClient:
             await asyncio.wait(handler_tasks, return_when=asyncio.FIRST_COMPLETED)
 
         except Exception as ex:  # pylint: disable=broad-except
+            _LOGGER.debug("exception(%s): %r", self.host, ex, exc_info=True)
             if not res.done():
                 res.set_exception(ex)
         finally:
@@ -265,25 +260,6 @@ class WebOsClient:
                     except asyncio.CancelledError:
                         pass
 
-    async def ping_handler(self, web_socket, interval, timeout):
-        """Ping Handler loop."""
-        try:
-            while True:
-                await asyncio.sleep(interval)
-                # In the "Suspend" state the tv can keep a connection alive,
-                # but will not respond to pings
-                if self._power_state.get("state") != "Suspend":
-                    ping_waiter = await web_socket.ping()
-                    if timeout is not None:
-                        await asyncio.wait_for(ping_waiter, timeout=timeout)
-        except (
-            asyncio.TimeoutError,
-            asyncio.CancelledError,
-            websockets.exceptions.ConnectionClosedError,
-            websockets.exceptions.ConnectionClosedOK,
-        ):
-            pass
-
     @staticmethod
     async def callback_handler(queue, callback, future):
         """Handle callbacks."""
@@ -305,6 +281,7 @@ class WebOsClient:
         try:
             async for raw_msg in web_socket:
                 if callbacks or futures:
+                    _LOGGER.debug("recv(%s): %s", self.host, raw_msg)
                     msg = json.loads(raw_msg)
                     uid = msg.get("id")
                     callback = self.callbacks.get(uid)
@@ -595,6 +572,7 @@ class WebOsClient:
         if self.connection is None:
             raise WebOsTvCommandError("Not connected, can't execute command.")
 
+        _LOGGER.debug("send(%s): %s", self.host, message)
         await self.connection.send(json.dumps(message))
 
     async def request(self, uri, payload=None, cmd_type="request", uid=None):
@@ -653,6 +631,7 @@ class WebOsClient:
         if self.input_connection is None:
             raise WebOsTvCommandError("Couldn't execute input command.")
 
+        _LOGGER.debug("send(%s): %s", self.host, message)
         await self.input_connection.send(message)
 
     # high level request handling
